@@ -9,7 +9,7 @@ Good luck
 """
 
 from functools import wraps
-from ._check_input import _CheckInput
+from NBprocessing.src._check_input import _CheckInput
 
 def _missing_values_checker(func):
     """
